<?php

namespace Teknisa\CADEST\Services;


use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class ParaVendasImposto {
	
	protected $entityManager;

	public function __construct(\Doctrine\ORM\EntityManager $entityManager)  {
		$this->entityManager = $entityManager;
		$this->connection = $entityManager->getConnection();
	}
	
	public function getTipoImposto($CDFILIAL, $NRORG){
		$params = array( 
			':CDFILIAL'=> $CDFILIAL,
			':NRORG'   => $NRORG
		);
		return $this->entityManager->getConnection()->fetchAll(self::TIPO_IMPOSTO, $params);
	}
	
	public function deleteProdutosImposto($products) {
		try {
			foreach($products as $product) {
				$this->entityManager->getConnection()->executeQuery(self::DELETE_IMPOSTO_PRODUTO, $product);
			}
		} catch(\Exception $e) {
			var_dump($e);
		}
	}
	
	public function deleteProdutoImposto($product) {
		try {
			$params = array(
				"CDPRODUTO" => $product["CDPRODUTO"],
				"NRORG" 	=> $product["NRORG"],
				"CDIMPOSTO" => $product["CDIMPOSTO"],
				"CDFILIAL"	=> $product["CDFILIAL"] 
			);
			$this->entityManager->getConnection()->executeQuery(self::DELETE_IMPOSTO_PRODUTO, $params);
		} catch(\Exception $e) {
			var_dump($e->getMessage());
		}
	}
	
	public function saveProdutosImposto($products, $params) {
		try {	
			foreach($products as $product) {
				$row = array();
				foreach($params as $key => $value) {
					$row[$key] = $value;
				}
				$row['CDPRODUTO'] = $product['CDPRODUTO'];
				$this->entityManager->getConnection()->executeQuery(self::INSERE_IMPOSTO_PRODUTO, $row);
			}
		} catch(\Exception $e) {
			var_dump($e);
		}
	}

	public function saveProdutoImposto($product, $CDFILIAL) {
		try {	
			$row = array();
			foreach($product as $key => $value) {
				$row[$key] = $value;
			}
			$row['CDFILIAL'] = $CDFILIAL;

			$this->entityManager->getConnection()->executeQuery(self::INSERE_IMPOSTO_PRODUTO, $row);
		} catch(\Exception $e) {
			var_dump($e);
		}
	}
	
	public function generateAliquote ($row) {
        $row["P_CDREGRAFISC"]  = $this->buildInputParam("P_CDREGRAFISC", $row["CDFILIAL"]);
        
        $this->genAliProcedure($row);
    }
    
    private function buildInputParam ($paramName, $paramValue) {
        return new Param($paramName, Param::PARAM_INPUT, $paramValue, Param::PARAM_TYPE_STR, strlen($paramValue));
    }
    
    public function genAliProcedure ($params) {
	    try{  
	        $storedProcedure = new StoredProcedure($this->connection, 'GERA_ALIQUOTA_VND');
	        $storedProcedure->addParam($params["P_CDREGRAFISC"]);
	        $storedProcedure->execute();
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function checkImposto($row, $CDFILIAL){
    	$return = array(
    		"showMessage" 		=> false,
			"message" 	=> ''
			);
    	$params = array(
				"NRORG" 		=> $row["NRORG"],
				"CDNVPRODUTO" 	=> $row["CDNVPRODUTO"],
				"CDARVPROD" 	=> $row["CDARVPROD"],
				"CDFILIAL"		=> $CDFILIAL 
			);
        $adqModProdFili = $this->entityManager->getConnection()->fetchAssoc(self::adqModProdFili, $params);
    	$adqGrupoPDV = $this->entityManager->getConnection()->fetchAssoc(self::adqGrupoPDV, $params);
    	$cdSegMer = $adqGrupoPDV['CDSEGMER'];
    	$params['CDSEGMER'] = $adqGrupoPDV['CDSEGMER'];
    	$dataSourceName = '';
    	if($adqModProdFili['IDUTMODPRODFIL'] == 'S'){
    		$filterModProd = $this->entityManager->getConnection()->fetchAssoc(self::filterModProd, $params);
    		if(!$filterModProd){
	    				 $return['showMessage'] = true;
	    				 $return['message'] = "O produto não se encontra em nenhum modulo de produto associado a filial.";
    				}
    	}else{
    		if(!empty($adqGrupoPDV['CDGRPRODPDV'])){
    			if(!empty($adqGrupoPDV['CDSEGMER'])){
    				$params['CDSEGMER'] = $adqGrupoPDV['CDSEGMER'];
    				// Utiliza família / segmento
    				$filterImpProdSegFam = $this->entityManager->getConnection()->fetchAssoc(self::filterImpProdSegFam, $params);
    				if(!$filterImpProdSegFam){
	    				 $return['showMessage'] = true;
	    				 $return['message'] = "O produto não se encontra em nenhuma familia e segmento de produto associado a filial.";
    				}
    			}else{
    				// Utiliza família
    				$filterImpProdFamilia = $this->entityManager->getConnection()->fetchAssoc(self::filterImpProdFamilia, $params);
    				if(!$filterImpProdFamilia){
	    				 $return['showMessage'] = true;
	    				 $return['message'] = "O produto não se encontra em nenhuma familia de produto associado a filial.";
    				}
    			}
    		}else{
    			if(!empty($adqGrupoPDV['CDSEGMER'])){
    				$params['CDSEGMER'] = $adqGrupoPDV['CDSEGMER'];
    				// Utiliza segmento
    				$filterImpProdSegmento = $this->entityManager->getConnection()->fetchAssoc(self::filterImpProdSegmento, $params);
    				if(!$filterImpProdSegmento){
	    				 $return['showMessage'] = true;
	    				 $return['message'] = "O produto não se encontra em nenhum segmento de produto associado a filial.";
    				}
    			}
    		}
    	}
    	return $return;
    }
    
    public function getProd($row, $CDPRODUTO) {
		try {
			$params = array(
				':CDFILIAL'  =>  $CDPRODUTO,
				':CDPRODUTO' =>	 $row['PRODUTO']
			);
			return $this->entityManager->getConnection()->fetchAll(self::GETPROD, $params);
	    } catch(\Exception $e) {
			var_dump($e);
		}
	}
	    
    const GETPROD = "
        SELECT DISTINCT 1 FROM PRODFILI WHERE CDPRODUTO = :CDPRODUTO AND CDFILIAL = :CDFILIAL
    ";
    
    public function getFilialProd($row, $CDPRODUTO) {
		try {
			$params = array(
				':CDPRODUTO'  =>  $CDPRODUTO
			);
			return $this->entityManager->getConnection()->fetchAll(self::GET_FILIAIS, $params);
	    } catch(\Exception $e) {
			var_dump($e);
		}
	}
	    
    const GET_FILIAIS = "
        SELECT CDFILIAL FROM ALIQIMPFIS WHERE CDPRODUTO = :CDPRODUTO
    ";
    
    public function saveIDUTILIMP($row, $CDPRODUTO, $FILIAL) {
		try {
		$params = array(
			':CDPRODUTO'  =>  $CDPRODUTO,
			':PRODUTO'    =>  $row['PRODUTO'],
			':NRORG'	  =>  $row['NRORG'],
			':CDFILIPROD' =>  $FILIAL
		);
		$result = $this->entityManager->getConnection()->fetchAssoc(self::GET_IMPOSTOS, $params);
		if(isset($result['CDIMPOSTO'])){
			$params = array (
	            ':CDPRODUTO'            =>     $CDPRODUTO,
				':CDIMPOSTO'            =>     $result['CDIMPOSTO'],
				':VRPEALIMPFIS'         =>     $result['VRPEALIMPFIS'],
				':IDTPIMPOSFIS'         =>     $result['IDTPIMPOSFIS'],
				':CDFILIAL'             =>     $FILIAL,
				':IDINCIDEPISCOF'       =>     $result['IDINCIDEPISCOF'],
				':VRALIQIBPT'           =>     $result['VRALIQIBPT'],
				':VRALIQIBPTES'         =>     $result['VRALIQIBPTES'],
				':CDCSTICMS'            =>     $result['CDCSTICMS'],
				':CDCSTPISCOF'          =>     $result['CDCSTPISCOF'],
				':CDCFOPPFIS'           =>     $result['CDCFOPPFIS'],
				':VRALIQPIS'            =>     $result['VRALIQPIS'],
				':VRALIQCOFINS'         =>     $result['VRALIQCOFINS'],
				':VRPERCREDUCAO'        =>     $result['VRPERCREDUCAO'],
				':IDMODALBASECALC'      =>     $result['IDMODALBASECALC'],
				':CDCEST'               =>     $result['CDCEST'],
				':NRORG'                =>     $result['NRORG'],
				':VRALIQFCP'            =>     $result['VRALIQFCP'],
				':VRPEALIMPFISEF'       =>     $result['VRPEALIMPFISEF'],
				':VRPERCREDUCAOEF'      =>     $result['VRPERCREDUCAOEF'],
				':CDCBENEF'             =>     $result['CDCBENEF'],
				':VRALIQICMSDES'        =>     $result['VRALIQICMSDES'],
				':VRALIQISS'            =>     $result['VRALIQISS'],
				':CDSERVICOISS'         =>     $result['CDSERVICOISS'],
				':CDITEMLISTASERV'      =>     $result['CDITEMLISTASERV'],
				':IDEXIGIBILISS'        =>     $result['IDEXIGIBILISS'],
				':IDINCENTIVOISS'       =>     $result['IDINCENTIVOISS']
	        );
		          
			$this->entityManager->getConnection()->executeQuery(self::UPDATE_IMPOSTOS, $params);
		}
	    } catch(\Exception $e) {
	      var_dump($e);
		}
	}
	    
    const GET_IMPOSTOS = "
        SELECT CDIMPOSTO, VRPEALIMPFISEF, VRALIQICMSDES, VRALIQISS, CDSERVICOISS, IDINCENTIVOISS, IDEXIGIBILISS, CDITEMLISTASERV, CDCBENEF, VRPERCREDUCAOEF, VRALIQFCP, VRPEALIMPFIS, IDTPIMPOSFIS, IDINCIDEPISCOF, VRALIQIBPT, VRALIQIBPTES, CDCSTICMS, CDCSTPISCOF, CDCFOPPFIS, REPLACE(VRALIQPIS, ',', '.') AS VRALIQPIS, REPLACE(VRALIQCOFINS, ',', '.') AS VRALIQCOFINS, VRPERCREDUCAO, IDMODALBASECALC, CDCEST, NRORG FROM ALIQIMPFIS AL WHERE CDPRODUTO = :PRODUTO AND CDFILIAL = :CDFILIPROD AND NRORG = :NRORG
    ";
    
    const UPDATE_IMPOSTOS = "
        UPDATE 
		  ALIQIMPFIS 
		SET 
		  CDIMPOSTO         = :CDIMPOSTO,
		  VRPEALIMPFIS      = :VRPEALIMPFIS, 
		  VRPERCREDUCAO     = :VRPERCREDUCAO, 
		  IDMODALBASECALC   = :IDMODALBASECALC, 
		  IDINCIDEPISCOF    = :IDINCIDEPISCOF, 
		  VRALIQIBPT        = :VRALIQIBPT, 
		  VRALIQIBPTES      = :VRALIQIBPTES, 
		  CDCFOPPFIS        = :CDCFOPPFIS, 
		  CDCSTICMS         = :CDCSTICMS, 
		  CDCSTPISCOF       = :CDCSTPISCOF, 
		  VRALIQPIS         = :VRALIQPIS, 
		  VRALIQCOFINS      = :VRALIQCOFINS, 
		  CDCEST            = :CDCEST, 
		  VRALIQFCP         = :VRALIQFCP, 
		  VRPEALIMPFISEF    = :VRPEALIMPFISEF, 
		  VRPERCREDUCAOEF   = :VRPERCREDUCAOEF, 
		  CDCBENEF          = :CDCBENEF, 
		  VRALIQICMSDES     = :VRALIQICMSDES, 
		  VRALIQISS         = :VRALIQISS,
		  CDSERVICOISS      = :CDSERVICOISS, 
		  CDITEMLISTASERV   = :CDITEMLISTASERV,
		  IDEXIGIBILISS     = :IDEXIGIBILISS, 
		  IDINCENTIVOISS    = :IDINCENTIVOISS
		WHERE 
		  CDPRODUTO     = :CDPRODUTO
		  AND CDFILIAL  = :CDFILIAL 
		  AND NRORG     = :NRORG
    ";
  
    public function saveIDUTILNCM($row, $CDPRODUTO) {
		try {
		  $params = array(
	        ':CDPRODUTO'  =>  $CDPRODUTO,
			':PRODUTO'    =>  $row['PRODUTO'],
			':NRORG'	  =>  $row['NRORG']
	      );
		      
		  $result = $this->entityManager->getConnection()->fetchAssoc(self::GET_CDCLASFISC, $params);
		  $params[':NCM'] = $result['CDCLASFISC'];
		  $this->entityManager->getConnection()->executeQuery(self::UPDATE_NCM, $params);
		} catch(\Exception $e) {
		  var_dump($e);
		}
	}
	
	const GET_CDCLASFISC = "
	    SELECT CDCLASFISC
	      FROM PRODUTO
	    WHERE
	       CDPRODUTO    = :PRODUTO
	       AND NRORG = :NRORG
	";
	
	const UPDATE_NCM = "
	    UPDATE PRODUTO
	      SET CDCLASFISC = :NCM
	    WHERE
	       CDPRODUTO    = :CDPRODUTO
	       AND NRORG = :NRORG
	";
	
	public function saveIDUTILSETORPROD($row, $CDPRODUTO) {
		try {
			$params = array(
				':PRODUTO'    =>  $row['PRODUTO'],
				':NRORG'	  =>  $row['NRORG']
			);
		      
			 $setores = $this->entityManager->getConnection()->fetchAll(self::GET_SETOR, $params);
			 
			 foreach($setores as $setor){
			 	$params = array(
					':PRODUTO'    =>  $row['PRODUTO'],
					':NRORG'	  =>  $row['NRORG'],
					':CDSETOR'	  =>  $setor['CDSETOR']
				);
				$paramOrig		= $this->entityManager->getConnection()->fetchAll(self::GET_PARAM_PROD, $params);
				$obsOrigem		= $this->entityManager->getConnection()->fetchAll(self::GET_OBS_PRODUTOS, $params);
				
				$paramDestino = array (
					':CDPRODUTO'    		=> $CDPRODUTO,
					':NRORG'	  			=> $row['NRORG'],
					':CDSETOR'				=> $setor['CDSETOR'],
					':NRTEMPOPROD' 			=> isset($paramOrig[0]['NRTEMPOPROD'])?$paramOrig[0]['NRTEMPOPROD']:'',
					':NRTEMPOEXIB' 			=> isset($paramOrig[0]['NRTEMPOEXIB'])?$paramOrig[0]['NRTEMPOEXIB']:'',
					':IDRESUMOPRODKDS' 		=> isset($paramOrig[0]['IDRESUMOPRODKDS'])?$paramOrig[0]['IDRESUMOPRODKDS']:'',
					':IDRESTRICAOORIGEM'	=> isset($paramOrig[0]['IDRESTRICAOORIGEM'])?$paramOrig[0]['IDRESTRICAOORIGEM']:'',
					':DSAPELIDORESUMO' 		=> isset($paramOrig[0]['DSAPELIDORESUMO'])?$paramOrig[0]['DSAPELIDORESUMO']:'',
					':IDIMPRPRODPICK'		=> isset($paramOrig[0]['IDIMPRPRODPICK'])?$paramOrig[0]['IDIMPRPRODPICK']:'',
					':IDPRODPRIORIDADE' 	=> isset($paramOrig[0]['IDPRODPRIORIDADE'])?$paramOrig[0]['IDPRODPRIORIDADE']:'',
					':IDIMPPRODAPETIC' 		=> isset($paramOrig[0]['IDIMPPRODAPETIC'])?$paramOrig[0]['IDIMPPRODAPETIC']:''
				);
				
				$exist = $this->entityManager->getConnection()->fetchAll(self::VERIF_EXIST_PROD, $paramDestino);
				
				if(!isset($exist[0])){
					$this->entityManager->getConnection()->executeQuery(self::INSERT_SETORPROD, $paramDestino);
					
					foreach($obsOrigem as $observação){
						$obsDestino = array (
							':CDPRODUTO'    	=> $CDPRODUTO,
							':CDSETOR'			=> $setor['CDSETOR'],
							':CDGRPOCOR' 		=> isset($observação['CDGRPOCOR'])?$observação['CDGRPOCOR']:'',
							':CDOCORR' 			=> isset($observação['CDOCORR'])?$observação['CDOCORR']:'',
							':NRTEMPOPROD' 		=> isset($observação['NRTEMPOPROD'])?$observação['NRTEMPOPROD']:'',
							':IDATIVO' 			=> isset($observação['IDATIVO'])?$observação['IDATIVO']:'',
							':NRORG'			=>  $row['NRORG']
						);
						
						$this->entityManager->getConnection()->executeQuery(self::INSERT_OBS_PRODUTOS, $obsDestino);
					}
				} else {
					$this->entityManager->getConnection()->executeQuery(self::UPDATE_SETORPROD, $paramDestino);
					
					foreach($obsOrigem as $observação){
						$obsDestino = array (
							':CDPRODUTO'    	=> $CDPRODUTO,
							':CDSETOR'			=> $setor['CDSETOR'],
							':CDGRPOCOR' 		=> isset($observação['CDGRPOCOR'])?$observação['CDGRPOCOR']:'',
							':CDOCORR' 			=> isset($observação['CDOCORR'])?$observação['CDOCORR']:'',
							':NRTEMPOPROD' 		=> isset($observação['NRTEMPOPROD'])?$observação['NRTEMPOPROD']:'',
							':IDATIVO' 			=> isset($observação['IDATIVO'])?$observação['IDATIVO']:'',
							':NRORG'			=>  $row['NRORG']
						);
						
						$existObs = $this->entityManager->getConnection()->fetchAll(self::VERIF_OBS_PRODUTOS, $obsDestino);

						if(!isset($existObs[0])){
							$this->entityManager->getConnection()->executeQuery(self::INSERT_OBS_PRODUTOS, $obsDestino);
						} else {
							$this->entityManager->getConnection()->executeQuery(self::UPDATE_OBS_PRODUTOS, $obsDestino);
						}
					}
				}
			}
		} catch(\Exception $e) {
		  var_dump($e);
		}
	}	
	
	const UPDATE_OBS_PRODUTOS = "
		UPDATE SETORPRODOBS SET
			NRTEMPOPROD			=	:NRTEMPOPROD
		WHERE CDPRODUTO			=	:CDPRODUTO
			AND NRORG			=	:NRORG
			AND CDSETOR			=	:CDSETOR
			AND CDGRPOCOR		=	:CDGRPOCOR
			AND CDOCORR			=	:CDOCORR
	";

	const VERIF_OBS_PRODUTOS = "
		SELECT 1
		FROM SETORPRODOBS
		WHERE CDPRODUTO = :CDPRODUTO
		AND   CDSETOR   = :CDSETOR
		AND	  CDGRPOCOR = :CDGRPOCOR
		AND   CDOCORR   = :CDOCORR
	";
	
	const INSERT_OBS_PRODUTOS = "
		INSERT INTO SETORPRODOBS
			(CDPRODUTO, CDSETOR, CDGRPOCOR, CDOCORR, NRTEMPOPROD, IDATIVO, NRORG, DTULTATU, DTINCLUSAO, NRORGINCLUSAO, NRORGULTATU)
		VALUES
			(:CDPRODUTO, :CDSETOR, :CDGRPOCOR, :CDOCORR, :NRTEMPOPROD, :IDATIVO, :NRORG, SYSDATE, SYSDATE, :NRORG, :NRORG)
	";

	const GET_OBS_PRODUTOS = "
		SELECT CDGRPOCOR, CDOCORR, NRTEMPOPROD, IDATIVO
		FROM SETORPRODOBS
		WHERE CDPRODUTO = :PRODUTO
		AND   CDSETOR   = :CDSETOR
	";
	
	const INSERT_SETORPROD = "INSERT INTO SETORPRODUTO
		(CDPRODUTO, NRORG, CDSETOR, NRTEMPOPROD, NRTEMPOEXIB, IDRESUMOPRODKDS, IDRESTRICAOORIGEM, DSAPELIDORESUMO, IDIMPRPRODPICK, IDPRODPRIORIDADE, IDIMPPRODAPETIC)
	VALUES
		(:CDPRODUTO, :NRORG, :CDSETOR, :NRTEMPOPROD, :NRTEMPOEXIB, :IDRESUMOPRODKDS, :IDRESTRICAOORIGEM, :DSAPELIDORESUMO, :IDIMPRPRODPICK, :IDPRODPRIORIDADE, :IDIMPPRODAPETIC)
	";
	
	const UPDATE_SETORPROD = "
		UPDATE SETORPRODUTO SET
			NRTEMPOPROD			=	:NRTEMPOPROD,
			NRTEMPOEXIB			=	:NRTEMPOEXIB,
			IDRESUMOPRODKDS		=	:IDRESUMOPRODKDS,
			IDRESTRICAOORIGEM	=	:IDRESTRICAOORIGEM,
			DSAPELIDORESUMO		=	:DSAPELIDORESUMO,
			IDIMPRPRODPICK		=	:IDIMPRPRODPICK,
			IDPRODPRIORIDADE	=	:IDPRODPRIORIDADE,
			IDIMPPRODAPETIC		=	:IDIMPPRODAPETIC
		WHERE CDPRODUTO			=	:CDPRODUTO
			AND NRORG			=	:NRORG
			AND CDSETOR			=	:CDSETOR
	";
	
	const GET_SETOR = "
   SELECT CDSETOR
	     FROM SETORPRODUTO
	   WHERE
	      CDPRODUTO	= :PRODUTO
	      AND NRORG = :NRORG
	";
	
	const VERIF_EXIST_PROD = "
   SELECT 1
     FROM SETORPRODUTO
   WHERE CDSETOR = :CDSETOR
      AND CDPRODUTO	= :CDPRODUTO
      AND NRORG = :NRORG
	";
	
	const GET_PARAM_PROD = "
   SELECT DSAPELIDORESUMO, NRTEMPOEXIB, NRTEMPOPROD, IDRESUMOPRODKDS, IDRESTRICAOORIGEM, IDIMPRPRODPICK, IDPRODPRIORIDADE, IDIMPPRODAPETIC
     FROM SETORPRODUTO
   WHERE CDSETOR = :CDSETOR
      AND CDPRODUTO	= :PRODUTO
      AND NRORG = :NRORG
	";
	
	public function saveIDUTILPREC($row, $CDPRODUTO, $FILIAL) {
		try {
			$params = array(
				':CDPRODUTO'  =>  $CDPRODUTO,
				':PRODUTO'    =>  $row['PRODUTO'],
				':NRORG'	  =>  $row['NRORG'],
				':CDFILIPROD' =>  $FILIAL
			);
			
			$tabLocal = $this->entityManager->getConnection()->fetchAll(self::GET_PRECO_LOCAL, $params);
			foreach($tabLocal as $result){
				
				if(isset($result['CDTABEPREC'])){
						$params = array(
			            ':CDPRODUTO'        => isset($CDPRODUTO)? $CDPRODUTO:'',
			            ':CDPRPAITABPR'     => isset($CDPRODUTO)? $CDPRODUTO:'',
			            ':CDFILIAL'         => $FILIAL,
			            ':PRODUTO'          => isset($row['PRODUTO'])?$row['PRODUTO']:'',
			            ':CDTABEPREC'   	=> isset($result['CDTABEPREC'])?$result['CDTABEPREC']:'',
			            ':VRCUSTITEM'   	=> isset($result['VRCUSTITEM'])?$result['VRCUSTITEM']:'',
			            ':VRPRECITEMCMD'    => isset($result['VRPRECITEMCMD'])?$result['VRPRECITEMCMD']:'',
			            ':VRPRECITEMDLV'    => isset($result['VRPRECITEMDLV'])?$result['VRPRECITEMDLV']:'',
			            ':HRINIVENPROD'     => isset($result['HRINIVENPROD'])?$result['HRINIVENPROD']:'', 
			            ':HRFIMVENPROD'     => isset($result['HRFIMVENPROD'])?$result['HRFIMVENPROD']:'', 
			            ':VRPRECITEM'       => isset($result['VRPRECITEM'])?$result['VRPRECITEM']:'', 
			            ':VRPRECITEMCL'     => isset($result['VRPRECITEMCL'])?$result['VRPRECITEMCL']:'', 
			            ':DTINIVGPREC'      => isset($result['DTINIVGPREC'])? substr($result['DTINIVGPREC'],0,10):'', 
			            ':IDPRECVARIA'      => isset($result['IDPRECVARIA'])?$result['IDPRECVARIA']:'', 
			            ':VRPRESUGITEM'     => isset($result['VRPRESUGITEM'])?$result['VRPRESUGITEM']:'', 
			            ':IDPRODPROMOC'     => isset($result['IDPRODPROMOC'])?$result['IDPRODPROMOC']:'',
			            ':IDATIVO'			=> isset($result['IDATIVO'])?$result['IDATIVO']:'',
			            ':CDOPERULTATU'		=> isset($row['CDOPERADOR'])?$row['CDOPERADOR']:'',
			            ':CDOPERINCLUSAO'	=> isset($row['CDOPERADOR'])?$row['CDOPERADOR']:'',
			            ':DTULTATU'			=> isset($CDPRODUTO)?date('d/m/Y'):'',
			            ':DTINCLUSAO'		=> isset($CDPRODUTO)?date('d/m/Y'):'',
			            ':NRORGULTATU'		=> $row['NRORG'],
			            ':NRORGINCLUSAO'	=> $row['NRORG'],
						':NRORG'    		=> $row['NRORG']
					);
					$exists = $this->entityManager->getConnection()->fetchAll(self::CHECK_PROD_TAB_LOCAL, $params);
					if ($exists == null){
						$this->entityManager->getConnection()->executeQuery(self::INSERT_PRECO_LOCAL, $params);
					}
					else{
						$this->entityManager->getConnection()->executeQuery(self::UPDATE_PRECO_LOCAL, $params);
					}
				}
			}
			
			$params = array(
				':CDPRODUTO'  =>  $CDPRODUTO,
				':PRODUTO'    =>  $row['PRODUTO'],
				':NRORG'	  =>  $row['NRORG'],
				':CDFILIPROD' =>  $FILIAL
			);
			
			$tabGeral = $this->entityManager->getConnection()->fetchAll(self::GET_PRECO_GERAL, $params);
			foreach($tabGeral as $result){
				
				if(isset($result['CDTABEPREC'])){
						$params = array(
			            ':CDPRODUTO'        => isset($CDPRODUTO)? $CDPRODUTO:'',
			            ':CDPRPAITABPR'     => isset($CDPRODUTO)? $CDPRODUTO:'',
			            ':CDFILIAL'         => $FILIAL,
			            ':PRODUTO'          => isset($row['PRODUTO'])?$row['PRODUTO']:'',
			            ':CDTABEPREC'   	=> isset($result['CDTABEPREC'])?$result['CDTABEPREC']:'',
			            ':VRCUSTITEM'   	=> isset($result['VRCUSTITEM'])?$result['VRCUSTITEM']:'',
			            ':VRPRECITEMCMD'    => isset($result['VRPRECITEMCMD'])?$result['VRPRECITEMCMD']:'',
			            ':VRPRECITEMDLV'    => isset($result['VRPRECITEMDLV'])?$result['VRPRECITEMDLV']:'',
			            ':HRINIVENPROD'     => isset($result['HRINIVENPROD'])?$result['HRINIVENPROD']:'', 
			            ':HRFIMVENPROD'     => isset($result['HRFIMVENPROD'])?$result['HRFIMVENPROD']:'', 
			            ':VRPRECITEM'       => isset($result['VRPRECITEM'])?$result['VRPRECITEM']:'', 
			            ':VRPRECITEMCL'     => isset($result['VRPRECITEMCL'])?$result['VRPRECITEMCL']:'', 
			            ':DTINIVGPREC'      => isset($result['DTINIVGPREC'])? substr($result['DTINIVGPREC'],0,10):'', 
			            ':IDPRECVARIA'      => isset($result['IDPRECVARIA'])?$result['IDPRECVARIA']:'', 
			            ':VRPRESUGITEM'     => isset($result['VRPRESUGITEM'])?$result['VRPRESUGITEM']:'', 
			            ':IDPRODPROMOC'     => isset($result['IDPRODPROMOC'])?$result['IDPRODPROMOC']:'',
			            ':IDATIVO'			=> isset($result['IDATIVO'])?$result['IDATIVO']:'',
			            ':CDOPERULTATU'		=> isset($row['CDOPERADOR'])?$row['CDOPERADOR']:'',
			            ':CDOPERINCLUSAO'	=> isset($row['CDOPERADOR'])?$row['CDOPERADOR']:'',
			            ':DTULTATU'			=> isset($CDPRODUTO)?date('d/m/Y'):'',
			            ':DTINCLUSAO'		=> isset($CDPRODUTO)?date('d/m/Y'):'',
			            ':NRORGULTATU'		=> $row['NRORG'],
			            ':NRORGINCLUSAO'	=> $row['NRORG'],
						':NRORG'    		=> $row['NRORG']
					);
					$exists = $this->entityManager->getConnection()->fetchAll(self::CHECK_PROD_TAB_GERAL, $params);
					if ($exists == null){
						$this->entityManager->getConnection()->executeQuery(self::INSERT_PRECO_GERAL, $params);
					}
					else{
						$this->entityManager->getConnection()->executeQuery(self::UPDATE_PRECO_GERAL, $params);
					}
				}
			}
			
		} catch(\Exception $e) {
		  var_dump($e);
		}
	}
	
	const GET_PRECO_LOCAL = "
	    SELECT VRCUSTITEM, VRPRECITEMCMD, VRPRECITEMDLV, CDTABEPREC,  HRINIVENPROD,  HRFIMVENPROD,  VRPRECITEM,  VRPRECITEMCL,  DTINIVGPREC,  IDPRECVARIA,  VRPRESUGITEM,  IDPRODPROMOC, IDATIVO FROM ITEMPRECO WHERE CDPRODUTO = :PRODUTO AND CDFILIAL = :CDFILIPROD AND NRORG = :NRORG
	";
	
	const GET_PRECO_GERAL = "
	    SELECT VRCUSTITEM, VRPRECITEMCMD, VRPRECITEMDLV, CDTABEPREC,  HRINIVENPROD,  HRFIMVENPROD,  VRPRECITEM,  VRPRECITEMCL,  DTINIVGPREC,  IDPRECVARIA,  VRPRESUGITEM,  IDPRODPROMOC, IDATIVO FROM ITEMPRECO WHERE CDPRODUTO = :PRODUTO AND CDFILIAL = :CDFILIPROD AND NRORG = :NRORG
	";
	
	const UPDATE_PRECO_LOCAL = "
	    UPDATE ITEMPRECO SET
	      VRPRECITEM   = :VRPRECITEM,
	      VRCUSTITEM   = :VRCUSTITEM,
	      VRPRESUGITEM = :VRPRESUGITEM,
	      IDPRECVARIA  = :IDPRECVARIA,
	      VRPRECITEMCL = :VRPRECITEMCL,
	      IDPRODPROMOC = :IDPRODPROMOC,
	      HRINIVENPROD = :HRINIVENPROD,
	      HRFIMVENPROD = :HRFIMVENPROD,
	      VRPRECITEMDLV = :VRPRECITEMDLV,
	      VRPRECITEMCMD = :VRPRECITEMCMD
	    WHERE CDFILIAL     = :CDFILIAL 
	      AND CDPRODUTO    = :CDPRODUTO
	      AND CDTABEPREC   = :CDTABEPREC 
	      AND DTINIVGPREC  = :DTINIVGPREC
	      AND NRORG        = :NRORG
	";
	
	const UPDATE_PRECO_GERAL = "
	    UPDATE ITEMPRECO SET
	      VRPRECITEM   = :VRPRECITEM,
	      VRCUSTITEM   = :VRCUSTITEM,
	      VRPRESUGITEM = :VRPRESUGITEM,
	      IDPRECVARIA  = :IDPRECVARIA,
	      VRPRECITEMCL = :VRPRECITEMCL,
	      IDPRODPROMOC = :IDPRODPROMOC,
	      HRINIVENPROD = :HRINIVENPROD,
	      HRFIMVENPROD = :HRFIMVENPROD,
	      VRPRECITEMDLV = :VRPRECITEMDLV,
	      VRPRECITEMCMD = :VRPRECITEMCMD
	    WHERE CDFILIAL     = :CDFILIAL 
	      AND CDPRODUTO    = :CDPRODUTO
	      AND CDTABEPREC   = :CDTABEPREC 
	      AND DTINIVGPREC  = :DTINIVGPREC
	      AND NRORG        = :NRORG
	";
	
	const INSERT_PRECO_LOCAL = "INSERT INTO ITEMPRECO
	      (CDFILIAL,CDTABEPREC,DTINIVGPREC,CDPRODUTO,VRPRECITEM,VRCUSTITEM,VRPRESUGITEM,
	      IDPRECVARIA,VRPRECITEMCL,IDPRODPROMOC,CDPRPAITABPR,IDATIVO,CDOPERULTATU,DTULTATU,
	      NRORGULTATU,CDOPERINCLUSAO,DTINCLUSAO,NRORG,NRORGINCLUSAO, HRFIMVENPROD, HRINIVENPROD, VRPRECITEMCMD, VRPRECITEMDLV)
	    VALUES
	      (:CDFILIAL,:CDTABEPREC,:DTINIVGPREC,:CDPRODUTO,:VRPRECITEM,:VRCUSTITEM,:VRPRESUGITEM,
	      :IDPRECVARIA,:VRPRECITEMCL,:IDPRODPROMOC,:CDPRPAITABPR,:IDATIVO,:CDOPERULTATU,:DTULTATU,
	      :NRORGULTATU,:CDOPERINCLUSAO,:DTINCLUSAO,:NRORG,:NRORGINCLUSAO, :HRFIMVENPROD, :HRINIVENPROD, :VRPRECITEMCMD, :VRPRECITEMDLV)
    ";
	
	const INSERT_PRECO_GERAL = "INSERT INTO ITEMPRECO
	      (CDFILIAL,CDTABEPREC,DTINIVGPREC,CDPRODUTO,VRPRECITEM,VRCUSTITEM,VRPRESUGITEM,
	      IDPRECVARIA,VRPRECITEMCL,IDPRODPROMOC,CDPRPAITABPR,IDATIVO,CDOPERULTATU,DTULTATU,
	      NRORGULTATU,CDOPERINCLUSAO,DTINCLUSAO,NRORG,NRORGINCLUSAO, HRFIMVENPROD, HRINIVENPROD, VRPRECITEMCMD, VRPRECITEMDLV)
	    VALUES
	      (:CDFILIAL,:CDTABEPREC,:DTINIVGPREC,:CDPRODUTO,:VRPRECITEM,:VRCUSTITEM,:VRPRESUGITEM,
	      :IDPRECVARIA,:VRPRECITEMCL,:IDPRODPROMOC,:CDPRPAITABPR,:IDATIVO,:CDOPERULTATU,:DTULTATU,
	      :NRORGULTATU,:CDOPERINCLUSAO,:DTINCLUSAO,:NRORG,:NRORGINCLUSAO, :HRFIMVENPROD, :HRINIVENPROD, :VRPRECITEMCMD, :VRPRECITEMDLV)
    ";
     
     
    const CHECK_PROD_TAB_LOCAL = "        
    	SELECT * FROM ITEMPRECO 
    	WHERE CDFILIAL     = :CDFILIAL 
	      AND CDPRODUTO    = :CDPRODUTO
	      AND CDTABEPREC   = :CDTABEPREC 
	      AND DTINIVGPREC  = :DTINIVGPREC
	      AND NRORG        = :NRORG
   ";
   
    const CHECK_PROD_TAB_GERAL = "        
    	SELECT * FROM ITEMPRECO 
    	WHERE CDFILIAL     = :CDFILIAL 
	      AND CDPRODUTO    = :CDPRODUTO
	      AND CDTABEPREC   = :CDTABEPREC 
	      AND DTINIVGPREC  = :DTINIVGPREC
	      AND NRORG        = :NRORG
   ";
     
	public function saveIDUTILPARAMGER($row, $CDPRODUTO) {
		try {
		$params = array(
			':CDPRODUTO'  =>  $CDPRODUTO,
			':PRODUTO'    =>  $row['PRODUTO'],
			':NRORG'      =>  $row['NRORG']
		);
		
		
		
		$result = $this->entityManager->getConnection()->fetchAssoc(self::GET_PARAMGERAL, $params);
		$params = array(
			':CDPRODUTO'		=> $CDPRODUTO,
			':PRODUTO'  		=> $row['PRODUTO'],
			':DESCMINERAIS'		=> $result['DESCMINERAIS'], 
			':VRENRGNUTRI'		=> $result['VRENRGNUTRI'], 
			':QTDCARBNUTRI'		=> $result['QTDCARBNUTRI'], 
			':QTDPROTNUTRI'		=> $result['QTDPROTNUTRI'], 
			':QTDGTOTNUTRI'		=> $result['QTDGTOTNUTRI'], 
			':QTDGSATNUTRI'		=> $result['QTDGSATNUTRI'], 
			':QTDGTRANUTRI'		=> $result['QTDGTRANUTRI'], 
			':QTDFIBRANUTRI'	=> $result['QTDFIBRANUTRI'], 
			':QTDSODNUTRI'		=> $result['QTDSODNUTRI'], 
			':DSVITNUTRI'		=> $result['DSVITNUTRI'], 
			':IDCONTROLAREFIL'	=> $result['IDCONTROLAREFIL'], 
			':IDTPPRODDEBCONS'	=> $result['IDTPPRODDEBCONS'], 
			':IDPESAPROD'		=> $result['IDPESAPROD'], 
			':QTTARAPROD'		=> $result['QTTARAPROD'], 
			':IDCOBTXSERV'		=> $result['IDCOBTXSERV'], 
			':IDTIPOPROD'		=> $result['IDTIPOPROD'], 
			':CDPROTECLADO'		=> $result['CDPROTECLADO'], 
			':IDIMPPRODUTO'		=> $result['IDIMPPRODUTO'], 
			':IDIMPRODUVEZ'		=> $result['IDIMPRODUVEZ'], 
			':QTDIAVALPRODVND'	=> $result['QTDIAVALPRODVND'], 
			':DSDADOSFORNVND'	=> $result['DSDADOSFORNVND'], 
			':QTPORCAOVND'		=> $result['QTPORCAOVND'], 
			':DSINFADIPRODVND'	=> $result['DSINFADIPRODVND'], 
			':IDUNPORCAOVND'	=> $result['IDUNPORCAOVND'], 
			':IDPADEMEDCASVND'	=> $result['IDPADEMEDCASVND'], 
			':IDTIPOMEDCASVND'	=> $result['IDTIPOMEDCASVND'], 
			':QTMEDCASVND'		=> $result['QTMEDCASVND'], 
			':IDORIGPRODPR'		=> $result['IDORIGPRODPR'], 
			':IDSOLLOCIMP'		=> $result['IDSOLLOCIMP'], 
			':SGUNIDADE'		=> $result['SGUNIDADE'], 
			':CDNVPRODUTO'		=> $result['CDNVPRODUTO'], 
			':VRMINCONSUMODEB'	=> $result['VRMINCONSUMODEB'], 
			':QTMAXOBSERV'		=> $result['QTMAXOBSERV'], 
			':DSPRODVENDA'		=> $result['DSPRODVENDA'], 
			':DSPRODVENDEN'		=> $result['DSPRODVENDEN'], 
			':DSPRODVENDES'		=> $result['DSPRODVENDES'],
			':NRORG'    		=>  $row['NRORG']
		);
		
		$this->entityManager->getConnection()->executeQuery(self::UPDATE_PARAMGERAL, $params);
		} catch(\Exception $e) {
		  var_dump($e);
		}
	}
	
	const GET_PARAMGERAL = "
	    SELECT DESCMINERAIS, VRENRGNUTRI, QTDCARBNUTRI, QTDPROTNUTRI, QTDGTOTNUTRI, QTDGSATNUTRI, QTDGTRANUTRI, QTDFIBRANUTRI, QTDSODNUTRI, DSVITNUTRI, IDCONTROLAREFIL, IDTPPRODDEBCONS, IDPESAPROD, QTTARAPROD, IDCOBTXSERV, IDTIPOPROD, CDPROTECLADO, IDIMPPRODUTO, IDIMPRODUVEZ, QTDIAVALPRODVND, DSDADOSFORNVND, QTPORCAOVND, DSINFADIPRODVND, IDUNPORCAOVND, IDPADEMEDCASVND, IDTIPOMEDCASVND, QTMEDCASVND, IDORIGPRODPR, IDSOLLOCIMP, SGUNIDADE, CDNVPRODUTO, VRMINCONSUMODEB, QTMAXOBSERV, DSPRODVENDA, DSPRODVENDEN, DSPRODVENDES FROM PRODUTO WHERE NRORG = :NRORG AND CDPRODUTO = :PRODUTO
	";
	
	const UPDATE_PARAMGERAL = "
	    UPDATE PRODUTO
	       SET	
	    	DESCMINERAIS 	= :DESCMINERAIS, 
			VRENRGNUTRI 	= :VRENRGNUTRI, 
			QTDCARBNUTRI 	= :QTDCARBNUTRI,
			QTDPROTNUTRI 	= :QTDPROTNUTRI,
			QTDGTOTNUTRI 	= :QTDGTOTNUTRI, 
			QTDGSATNUTRI 	= :QTDGSATNUTRI, 
			QTDGTRANUTRI 	= :QTDGTRANUTRI, 
			QTDFIBRANUTRI 	= :QTDFIBRANUTRI, 
			QTDSODNUTRI 	= :QTDSODNUTRI, 
			DSVITNUTRI 		= :DSVITNUTRI, 
			IDCONTROLAREFIL = :IDCONTROLAREFIL, 
			IDTPPRODDEBCONS = :IDTPPRODDEBCONS, 
			IDPESAPROD 		= :IDPESAPROD, 
			QTTARAPROD 		= :QTTARAPROD, 
			IDCOBTXSERV 	= :IDCOBTXSERV, 
			IDTIPOPROD 		= :IDTIPOPROD, 
			CDPROTECLADO 	= :CDPROTECLADO, 
			IDIMPPRODUTO 	= :IDIMPPRODUTO, 
			IDIMPRODUVEZ 	= :IDIMPRODUVEZ, 
			QTDIAVALPRODVND = :QTDIAVALPRODVND, 
			DSDADOSFORNVND 	= :DSDADOSFORNVND, 
			QTPORCAOVND 	= :QTPORCAOVND, 
			DSINFADIPRODVND = :DSINFADIPRODVND, 
			IDUNPORCAOVND 	= :IDUNPORCAOVND, 
			IDPADEMEDCASVND = :IDPADEMEDCASVND, 
			IDTIPOMEDCASVND = :IDTIPOMEDCASVND, 
			QTMEDCASVND 	= :QTMEDCASVND, 
			IDORIGPRODPR 	= :IDORIGPRODPR, 
			IDSOLLOCIMP 	= :IDSOLLOCIMP, 
			SGUNIDADE 		= :SGUNIDADE, 
			CDNVPRODUTO 	= :CDNVPRODUTO, 
			VRMINCONSUMODEB = :VRMINCONSUMODEB, 
			QTMAXOBSERV 	= :QTMAXOBSERV, 
			DSPRODVENDA 	= :DSPRODVENDA, 
			DSPRODVENDEN 	= :DSPRODVENDEN, 
			DSPRODVENDES 	= :DSPRODVENDES
	    WHERE
	       CDPRODUTO    = :CDPRODUTO
	       AND NRORG = :NRORG
	";
	
	public function saveIDUTILCTRLEST($row, $CDPRODUTO, $FILIAL) {
		try {
		  $params = array(
	          ':CDPRODUTO'  =>  $CDPRODUTO,
	          ':PRODUTO'    =>  $row['PRODUTO'],
			  ':NRORG'      =>  $row['NRORG'],
			  ':CDFILIPROD'	=>  $FILIAL
	      );
		      
		  $result = $this->entityManager->getConnection()->fetchAssoc(self::GET_CRTLEST, $params);
		  $params[':CDFILIAL'] = $FILIAL;
		  $params[':IDCNTRESTOQ'] = isset($result['IDCNTRESTOQ'])?$result['IDCNTRESTOQ']:'S';
		  
		  $this->entityManager->getConnection()->executeQuery(self::UPDATE_CRTLEST, $params);
		} catch(\Exception $e) {
		  var_dump($e);
		}
	}
	
	const GET_CRTLEST = "
	    SELECT IDCNTRESTOQ
	      FROM PRODFILI
	    WHERE CDFILIAL = :CDFILIPROD
	    	AND CDPRODUTO    = :PRODUTO
	        AND NRORG = :NRORG
	";
	
	const UPDATE_CRTLEST = "
	    UPDATE PRODFILI
	      SET IDCNTRESTOQ = :IDCNTRESTOQ
	    WHERE CDFILIAL = :CDFILIAL
	    	AND CDPRODUTO    = :CDPRODUTO
	        AND NRORG = :NRORG
	";
	
    public function saveIDUTILPRODLOJA($row, $CDPRODUTO, $CDLOJA, $FILIAL) {
		try {
			$params = array(
				':CDPRODUTO'  =>  $CDPRODUTO,
				':PRODUTO'    =>  $row['PRODUTO'],
				':NRORG'      =>  $row['NRORG'],
				':CDLOJA'     =>  $CDLOJA,
				':CDFILIPROD' =>  $FILIAL
				
			);
			$result = $this->entityManager->getConnection()->fetchAssoc(self::GET_PRODLOJA, $params);

			if(isset($result['IDIMPCANITEM'])){
				$params = array(
					':CDPRODUTO'		=> $CDPRODUTO,
					':CDFILIAL' 		=> $FILIAL,
					':PRODUTO'  		=> $row['PRODUTO'],
					':NRORG'    		=> $row['NRORG'],
					':CDLOJA'   		=> $CDLOJA,
		            ':IDIMPCANITEM'     => $result['IDIMPCANITEM'], 
		            ':NRSEQIMPRPROD'    => isset($result['NRSEQIMPRPROD'])?$result['NRSEQIMPRPROD']:'', 
		            ':NRSEQIMPRPROD2'   => isset($result['NRSEQIMPRPROD2'])?$result['NRSEQIMPRPROD2']:'',
		            ':NRSEQIMPRPUXA'    => isset($result['NRSEQIMPRPUXA'])?$result['NRSEQIMPRPUXA']:'',
		            ':CDSETOR'          => isset($result['CDSETOR'])?$result['CDSETOR']:''
				);
				
				
				
				$exists = $this->entityManager->getConnection()->fetchAssoc(self::VALID_PRODLOJA, $params);
				
				$impressoras = $this->entityManager->getConnection()->fetchAll(self::VALID_IMPRES, $params);
				$arrayImpressora = '';
				foreach($impressoras as $impressora){
					$arrayImpressora = $arrayImpressora.'_'.$impressora['NRSEQIMPRLOJA'];
				}
				
				if(!(strpos($arrayImpressora, $params[':NRSEQIMPRPROD']))){
					$params[':NRSEQIMPRPROD'] = '';
				}
				if(!(strpos($arrayImpressora, $params[':NRSEQIMPRPROD2']))){
					$params[':NRSEQIMPRPROD2'] = '';
				}
				if(!(strpos($arrayImpressora, $params[':NRSEQIMPRPUXA']))){
					$params[':NRSEQIMPRPUXA'] = '';
				}
				
				if ($exists){
					
					$this->entityManager->getConnection()->executeQuery(self::UPDATE_PRODLOJA, $params);
				}
				else{
					
					$this->entityManager->getConnection()->executeQuery(self::INSERT_PRODLOJA, $params);
				}
				
				
			}
		} catch(\Exception $e) {
		  var_dump($e);
		}
	}
	
	const GET_PRODLOJA = "
	    SELECT IDIMPCANITEM, NRSEQIMPRPROD, NRSEQIMPRPROD2, NRSEQIMPRPUXA, CDSETOR FROM PRODLOJA WHERE CDFILIAL = :CDFILIPROD AND CDLOJA = :CDLOJA AND CDPRODUTO = :PRODUTO AND NRORG = :NRORG 
	";
	
	const VALID_PRODLOJA = "
	    SELECT 1 FROM PRODLOJA WHERE CDFILIAL = :CDFILIAL AND CDLOJA = :CDLOJA AND CDPRODUTO = :CDPRODUTO AND NRORG = :NRORG 
	";
	
	const VALID_IMPRES = "
		    SELECT A.NRSEQIMPRLOJA FROM IMPRLOJA A LEFT JOIN IMPRESSORA B ON A.CDIMPRESSORA = B.CDIMPRESSORA WHERE A.NRORG = :NRORG AND A.CDFILIAL = :CDFILIAL AND A.CDLOJA = :CDLOJA ORDER BY NRSEQIMPRLOJA
	";
	
	const UPDATE_PRODLOJA = "
	    UPDATE PRODLOJA
           SET IDIMPCANITEM = :IDIMPCANITEM, 
			CDSETOR = :CDSETOR, 
			NRSEQIMPRPROD = :NRSEQIMPRPROD,
			NRSEQIMPRPROD2 = :NRSEQIMPRPROD2,
			NRSEQIMPRPUXA = :NRSEQIMPRPUXA, 
			DTULTATUPLOJ = SYSDATE
         WHERE CDFILIAL  = :CDFILIAL
           AND CDLOJA    = :CDLOJA
           AND CDPRODUTO = :CDPRODUTO
           AND NRORG     = :NRORG
	";
	
	const INSERT_PRODLOJA = "
		INSERT INTO PRODLOJA
          (CDFILIAL, CDLOJA, CDPRODUTO, IDIMPCANITEM, CDSETOR, NRSEQIMPRPROD, NRSEQIMPRPROD2,
            NRSEQIMPRPUXA, CDPORIMPPROD, CDTIPIMPPROD, NRORG)
        VALUES
          (:CDFILIAL, :CDLOJA, :CDPRODUTO, :IDIMPCANITEM, :CDSETOR, :NRSEQIMPRPROD, :NRSEQIMPRPROD2,
            :NRSEQIMPRPUXA, ' ', '0', :NRORG)
	";
	
	public function saveIDUTILLAYOUT($row, $CDPRODUTO, $CDLOJA, $NMPRODUTO, $FILIAL) {
		try {
			$params = array(
				':CDPRODUTO'  =>  $CDPRODUTO,
				':CDFILIAL'   =>  $FILIAL,
				':PRODUTO'    =>  $row['PRODUTO'],
				':NRORG'      =>  $row['NRORG'],
				':CDLOJA'	  =>  $CDLOJA,
				':CDFILIPROD' =>  $FILIAL
			);
			
			$configs = $this->entityManager->getConnection()->fetchAll(self::GET_LAYOUT, $params);
			foreach ($configs as $result){
				$params[':NRCONFTELA'] = $result['NRCONFTELA'];
				$params[':NRBUTTONAUX'] = $result['NRBUTTONAUX'];
				$params[':NRPGCONFTAUX'] = $result['NRPGCONFTAUX'];
				$exists = $this->entityManager->getConnection()->fetchAll(self::VALID_LAYOUT, $params);
				
				$paramsInsert = array(
					':CDPRODUTO'		  => $CDPRODUTO,
					':CDFILIAL' 		  => $FILIAL,
					':NRCONFTELA'  		  => $result['NRCONFTELA'],
					':NRORG'    		  => $row['NRORG'],
					':IDTPBUTTON'         => $result['IDTPBUTTON'],
					':NRPGCONFTELA'       => $result['NRPGCONFTELA'],
					':IDTPBUTONAUX'       => $result['IDTPBUTONAUX'],
					':NRBUTTONAUX'        => $result['NRBUTTONAUX'],
					':NRPGCONFTAUX'       => $result['NRPGCONFTAUX'],
					':CDIDENTBUTON'       => $CDPRODUTO,
					':DSBUTTON'           => $NMPRODUTO,
					':NRCOLORTEXT'        => $result['NRCOLORTEXT'],
					':NRCOLORBACK'        => $result['NRCOLORBACK'],
					':DSMESSAGEBUT'       => $result['DSMESSAGEBUT'],
					':DSIMAGEMBUT'        => $result['DSIMAGEMBUT'],
					':DTULTATUITCT'       => $result['DTULTATUITCT'],
					':NRFONTETEXT'        => $result['NRFONTETEXT'],
					':CDATAPRODITM'       => $result['CDATAPRODITM'],
					':DTULTATU'           => $result['DTULTATU'],
					':NRORGULTATU'        => $result['NRORGULTATU'],
					':IDATIVO'            => $result['IDATIVO'],
					':CDNATPRODUTO'       => $result['CDNATPRODUTO'],
					':NRLIMPRODCOM'       => $result['NRLIMPRODCOM'],
					':DSENDEIMG'          => $result['DSENDEIMG'],
					':NRPGCONFTAUX2'      => $result['NRPGCONFTAUX2'],
					':NRBUTTONAUX2'       => $result['NRBUTTONAUX2'],
					':IDTPBUTONAUX2'      => $result['IDTPBUTONAUX2'],
					':DSENDEIMGAUX'       => $result['DSENDEIMGAUX'],
					':IDMODOMENU'         => $result['IDMODOMENU'],
					':DSBUTTONINGLES'     => $result['DSBUTTONINGLES'],
					':DSBUTTONESPANH'     => $result['DSBUTTONESPANH'],
					':IDEXIBEAPPCONS'     => $result['IDEXIBEAPPCONS'],
					':DSITMENUVENDA'      => $result['DSITMENUVENDA'],
					':IDSHOWTAA'          => $result['IDSHOWTAA'],
					':DTINIVIGENCIA'      => $result['DTINIVIGENCIA'],
					':IDORIGENDPOINT'     => $result['IDORIGENDPOINT'],
		            ':CDOPERULTATU'		  => isset($row['CDOPERADOR'])?$row['CDOPERADOR']:'',
		            ':CDOPERINCLUSAO'     => isset($row['CDOPERADOR'])?$row['CDOPERADOR']:'',
		            ':DTULTATU'			  => isset($CDPRODUTO)?date('d/m/Y'):'',
		            ':DTINCLUSAO'		  => isset($CDPRODUTO)?date('d/m/Y'):'',
		            ':NRORGULTATU'		  => $row['NRORG'],
		            ':NRORGINCLUSAO'	  => $row['NRORG'],
					':NRORG'    		  => $row['NRORG'],
					':CDLOJA'			  => $CDLOJA
				);
				

				if($exists && !empty($exists)){
					if(is_array($exists)){
						foreach($exists as $prodFil){
							$paramsInsert[':NRBUTTON'] = $prodFil['NRBUTTON'];
							$this->entityManager->getConnection()->executeQuery(self::UPDATE_LAYOUT, $paramsInsert);
						}
					} else {
						$paramsInsert[':NRBUTTON'] = $exists['NRBUTTON'];
						$this->entityManager->getConnection()->executeQuery(self::UPDATE_LAYOUT, $paramsInsert);
					}
					
				} else {
					$pos = $this->entityManager->getConnection()->fetchAssoc(self::GET_POSITION, $paramsInsert);
					$pagAnt = $pos['NEXTPAGE'] - 1;
					$pagAtual = $paramsInsert[':NRPGCONFTELA'];
					$paramsInsert[':NRBUTTON']		= $pos['NEXTBUTTON'];
					$paramsInsert[':NRPGCONFTELA']	= $pos['NEXTPAGE'];
					if ($pos['NEXTPAGE'] < 10){
						if($pos['NEXTBUTTON'] = '02' && ($pagAtual != $pos['NEXTPAGE']) && $pagAnt >= 0){
							$paramsInsert[':PGATUAL'] = $pagAtual;
							$buttonPos = $this->entityManager->getConnection()->fetchAssoc(self::VERIFYPOS, $paramsInsert);
							if($buttonPos){
								
								if($buttonPos['IDTPBUTTON'] != 9){
									$paramsInsert['CDPRODUTOBUTTON'] = $buttonPos['CDIDENTBUTON'];
									$this->entityManager->getConnection()->executeQuery(self::UPDATEPOS, $paramsInsert);
									$paramsInsert[':NRBUTTON'] = '03';
								}
							}
							if ($pagAnt > 0){
								$paramsInsert[':NRPGSETA'] = intval($paramsInsert[':NRPGCONFTELA']);
								$this->entityManager->getConnection()->executeQuery(self::INSERT_ARROW_LEFT,$paramsInsert);
							}
							$paramsInsert[':NRPGSETA'] = $pagAnt;
							$this->entityManager->getConnection()->executeQuery(self::INSERT_ARROW_RIGHT,$paramsInsert);
						}
						$this->entityManager->getConnection()->executeQuery(self::INSERT_LAYOUT, $paramsInsert);
					}
				}

			}
			
		} catch(\Exception $e) {
		  var_dump($e);
		}
	}
	
	const GET_LAYOUT = "
	    SELECT I.IDTPBUTTON, I.NRCONFTELA, I.NRBUTTON, I.NRPGCONFTELA, I.NRBUTTONAUX, I.IDTPBUTONAUX, I.NRPGCONFTAUX, I.CDIDENTBUTON, I.DSBUTTON, I.NRCOLORTEXT, I.NRCOLORBACK, I.DSMESSAGEBUT, I.DSIMAGEMBUT, I.DTULTATUITCT, I.NRFONTETEXT, I.CDATAPRODITM, I.NRORG, I.DTINCLUSAO, I.DTULTATU, I.NRORGINCLUSAO, I.CDOPERINCLUSAO, I.NRORGULTATU, I.CDOPERULTATU, I.IDATIVO, I.CDNATPRODUTO, I.NRLIMPRODCOM, I.DSENDEIMG, I.NRPGCONFTAUX2, I.NRBUTTONAUX2, I.IDTPBUTONAUX2, I.DSENDEIMGAUX, I.IDMODOMENU, I.DSBUTTONINGLES, I.DSBUTTONESPANH, I.IDEXIBEAPPCONS, I.DSITMENUVENDA, I.IDSHOWTAA, I.DTINIVIGENCIA, I.IDORIGENDPOINT FROM ITMENUCONFTE I JOIN CONFTELA C ON C.NRCONFTELA = I.NRCONFTELA WHERE I.NRORG = :NRORG AND I.CDIDENTBUTON = :PRODUTO AND I.CDFILIAL = :CDFILIPROD AND C.CDLOJA = :CDLOJA
	";
	
	const GET_POSITION = "
		SELECT
		    CASE
		        WHEN MAX(IT.NRBUTTON) + 1 > 35 THEN
		            LPAD(TO_CHAR(02),2,0)
		        ELSE
		            LPAD(TO_CHAR(MAX(IT.NRBUTTON) + 1), 2, 0)
		    END NEXTBUTTON,
		    CASE
		        WHEN MAX(IT.NRBUTTON) + 1 > 35 THEN
		            MAX(TO_NUMBER(IT.NRPGCONFTELA)) + 1
		        ELSE
		            MAX(TO_NUMBER(IT.NRPGCONFTELA))
		    END NEXTPAGE
		FROM
		         ITMENUCONFTE IT
		    JOIN CONFTELA C ON C.NRCONFTELA = IT.NRCONFTELA
		WHERE
		        IT.NRCONFTELA = :NRCONFTELA
		    AND IT.CDFILIAL = :CDFILIAL
		    AND IT.NRORG = :NRORG
		    AND C.CDLOJA = :CDLOJA
		    AND IT.IDTPBUTONAUX = '2'
		    AND IT.NRPGCONFTAUX = :NRPGCONFTAUX
		    AND IT.NRBUTTONAUX = :NRBUTTONAUX
	";
	
	const VALID_LAYOUT = "
    		SELECT IT.*, P.NMPRODUTO FROM ITMENUCONFTE IT JOIN CONFTELA C ON C.NRCONFTELA = IT.NRCONFTELA LEFT JOIN PRODUTO P ON P.CDPRODUTO = IT.CDIDENTBUTON WHERE IT.NRORG = :NRORG AND IT.CDIDENTBUTON = :CDPRODUTO AND IT.CDFILIAL = :CDFILIAL AND IT.NRCONFTELA = :NRCONFTELA AND C.CDLOJA = :CDLOJA AND IT.NRPGCONFTAUX = :NRPGCONFTAUX AND IT.NRBUTTONAUX = :NRBUTTONAUX
	";
	
	const VERIFYPOS = "
        	SELECT I.* FROM ITMENUCONFTE I JOIN CONFTELA C ON C.NRCONFTELA = I.NRCONFTELA WHERE I.NRORG = :NRORG AND I.NRBUTTON = '36' AND I.CDFILIAL = :CDFILIAL AND C.CDLOJA = :CDLOJA AND I.NRPGCONFTELA = :PGATUAL AND I.NRPGCONFTAUX = :NRPGCONFTAUX AND I.NRBUTTONAUX = :NRBUTTONAUX AND I.NRCONFTELA = :NRCONFTELA
	";
	
	const UPDATEPOS = "UPDATE ITMENUCONFTE
	    SET NRPGCONFTELA = (TO_NUMBER(NRPGCONFTELA)+1),
	        NRBUTTON = '02'
	    WHERE CDFILIAL = :CDFILIAL
	      AND NRCONFTELA = :NRCONFTELA 
	      AND NRORG = :NRORG
	      AND CDIDENTBUTON = :CDPRODUTOBUTTON
	      AND NRPGCONFTAUX = :NRPGCONFTAUX 
	      AND NRBUTTONAUX  = :NRBUTTONAUX
     ";
	
	
	const UPDATE_LAYOUT = "
	    UPDATE ITMENUCONFTE
           SET 
			NRCOLORTEXT         = :NRCOLORTEXT,
			NRCOLORBACK         = :NRCOLORBACK,
			DSMESSAGEBUT        = :DSMESSAGEBUT,
			DSIMAGEMBUT         = :DSIMAGEMBUT,
			DTULTATUITCT        = :DTULTATUITCT,
			NRFONTETEXT         = :NRFONTETEXT,
			DTULTATU            = :DTULTATU,
			NRORGULTATU         = :NRORGULTATU,
			IDATIVO             = :IDATIVO,
			NRLIMPRODCOM        = :NRLIMPRODCOM,
			DSENDEIMG           = :DSENDEIMG,
			DSENDEIMGAUX        = :DSENDEIMGAUX,
			IDMODOMENU          = :IDMODOMENU,
			DSBUTTONINGLES      = :DSBUTTONINGLES,
			DSBUTTONESPANH      = :DSBUTTONESPANH,
			IDEXIBEAPPCONS      = :IDEXIBEAPPCONS,
			DSITMENUVENDA       = :DSITMENUVENDA,
			IDSHOWTAA           = :IDSHOWTAA,
			DTINIVIGENCIA       = :DTINIVIGENCIA,
			IDORIGENDPOINT      = :IDORIGENDPOINT
         WHERE CDFILIAL 	= :CDFILIAL
           AND NRCONFTELA	= :NRCONFTELA
           AND CDIDENTBUTON = :CDPRODUTO
           AND NRORG    	= :NRORG
           AND NRBUTTON 	= :NRBUTTON
           AND NRPGCONFTAUX = :NRPGCONFTAUX 
           AND NRBUTTONAUX  = :NRBUTTONAUX
	";
	
	const INSERT_ARROW_RIGHT = "
		INSERT INTO ITMENUCONFTE 
		    (DTINIVIGENCIA, NRLIMPRODCOM, IDMODOMENU, DSBUTTONESPANH, DSBUTTONINGLES, NRPGCONFTAUX, IDTPBUTONAUX2, IDEXIBEAPPCONS, NRBUTTONAUX2, NRBUTTONAUX, NRBUTTON, NRPGCONFTAUX2, NRCONFTELA, CDATAPRODITM, DSBUTTON, IDTPBUTONAUX, NRPGCONFTELA, DSENDEIMG, NRCOLORBACK, NRCOLORTEXT, NRFONTETEXT, CDIDENTBUTON, IDTPBUTTON, CDFILIAL, DSMESSAGEBUT, DSIMAGEMBUT, NRORG, IDATIVO, DSITMENUVENDA, IDSHOWTAA, IDORIGENDPOINT, DTULTATU, DTINCLUSAO)
		VALUES 
		    (:DTINIVIGENCIA, '', '', '', '', :NRPGCONFTAUX, '2', 'S', :NRBUTTONAUX2, :NRBUTTONAUX, '36', '0', :NRCONFTELA, '', 'Navegador Direita', '2', :NRPGSETA, '', '33023', '0', '8', '', '9', :CDFILIAL, '', '', :NRORG, :IDATIVO, '', 'S', 'N', SYSDATE, SYSDATE)
	";
	const INSERT_ARROW_LEFT = "
		INSERT INTO ITMENUCONFTE 
		    (DTINIVIGENCIA, NRLIMPRODCOM, IDMODOMENU, DSBUTTONESPANH, DSBUTTONINGLES, NRPGCONFTAUX, IDTPBUTONAUX2, IDEXIBEAPPCONS, NRBUTTONAUX2, NRBUTTONAUX, NRBUTTON, NRPGCONFTAUX2, NRCONFTELA, CDATAPRODITM, DSBUTTON, IDTPBUTONAUX, NRPGCONFTELA, DSENDEIMG, NRCOLORBACK, NRCOLORTEXT, NRFONTETEXT, CDIDENTBUTON, IDTPBUTTON, CDFILIAL, DSMESSAGEBUT, DSIMAGEMBUT, NRORG, IDATIVO, DSITMENUVENDA, IDSHOWTAA, IDORIGENDPOINT,  DTULTATU, DTINCLUSAO)
		VALUES 
		    (:DTINIVIGENCIA, '', '', '', '', :NRPGCONFTAUX, '2', 'S', :NRBUTTONAUX2, :NRBUTTONAUX, '01', '0', :NRCONFTELA, '', 'Navegador Esquerda', '2', :NRPGSETA, '', '33023', '0', '8', '', 'A', :CDFILIAL, '', '', :NRORG, :IDATIVO, '', 'S', 'N', SYSDATE, SYSDATE)
	";
	
	const INSERT_LAYOUT = "
		INSERT INTO ITMENUCONFTE
			(CDFILIAL, NRCONFTELA, IDTPBUTTON, NRBUTTON, NRPGCONFTELA, NRBUTTONAUX, IDTPBUTONAUX, NRPGCONFTAUX, CDIDENTBUTON, DSBUTTON, NRCOLORTEXT, NRCOLORBACK, DSMESSAGEBUT, DSIMAGEMBUT, DTULTATUITCT, NRFONTETEXT, CDATAPRODITM, NRORG, DTINCLUSAO, DTULTATU, NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU, IDATIVO, CDNATPRODUTO, NRLIMPRODCOM, DSENDEIMG, NRPGCONFTAUX2, NRBUTTONAUX2, IDTPBUTONAUX2, DSENDEIMGAUX, IDMODOMENU, DSBUTTONINGLES, DSBUTTONESPANH, IDEXIBEAPPCONS, DSITMENUVENDA, IDSHOWTAA, DTINIVIGENCIA, IDORIGENDPOINT) 
		VALUES 
			(:CDFILIAL, :NRCONFTELA, :IDTPBUTTON, :NRBUTTON, :NRPGCONFTELA, :NRBUTTONAUX, :IDTPBUTONAUX, :NRPGCONFTAUX, :CDIDENTBUTON, :DSBUTTON, :NRCOLORTEXT, :NRCOLORBACK, :DSMESSAGEBUT, :DSIMAGEMBUT, :DTULTATUITCT, :NRFONTETEXT, :CDATAPRODITM, :NRORG, :DTINCLUSAO, :DTULTATU, :NRORGINCLUSAO, :CDOPERINCLUSAO, :NRORGULTATU, :CDOPERULTATU, :IDATIVO, :CDNATPRODUTO, :NRLIMPRODCOM, :DSENDEIMG, :NRPGCONFTAUX2, :NRBUTTONAUX2, :IDTPBUTONAUX2, :DSENDEIMGAUX, :IDMODOMENU, :DSBUTTONINGLES, :DSBUTTONESPANH, :IDEXIBEAPPCONS, :DSITMENUVENDA, :IDSHOWTAA, :DTINIVIGENCIA, :IDORIGENDPOINT)
	";
    
    const TIPO_IMPOSTO= "
        SELECT P.CDSITUTRIB, P.DSSITUTRIB 
          FROM FILIAL F 
          JOIN PARAMEMPRESA PF 
            ON F.CDEMPRESA = PF.CDEMPRESA 
           AND F.NRORG = PF.NRORG 
          JOIN PARAMCST P 
            ON P.NRORG = F.NRORG 
         WHERE (P.CDIMPOSTO = '00') 
           AND (P.IDENTRSAIDOP = 'S') 
           AND PF.CDSITUCRT = '3'
           AND F.CDFILIAL = :CDFILIAL
           AND F.NRORG = :NRORG
    ";
    const DELETE_IMPOSTO_PRODUTO = "
    	DELETE
    		FROM ALIQIMPFIS
    	WHERE CDFILIAL = :CDFILIAL
    		AND NRORG      = :NRORG
    		AND CDIMPOSTO  = :CDIMPOSTO
    		AND CDPRODUTO  = :CDPRODUTO
    ";
    const INSERE_IMPOSTO_PRODUTO = "    
    INSERT INTO ALIQIMPFIS 
      (VRPEALIMPFIS, VRPERCREDUCAO, IDMODALBASECALC, IDINCIDEPISCOF, VRALIQIBPT, 
       VRALIQIBPTES, CDCFOPPFIS, CDCSTICMS, CDCSTPISCOF, VRALIQPIS, VRALIQCOFINS,
       CDCEST, CDIMPOSTO, CDFILIAL, NRORG, CDPRODUTO, IDTPIMPOSFIS)
    VALUES 
      (:VRPEALIMPFIS, :VRPERCREDUCAO, :IDMODALBASECALC, :IDINCIDEPISCOF, :VRALIQIBPT, 
       :VRALIQIBPTES, :CDCFOPPFIS, :CDCSTICMS, :CDCSTPISCOF, :VRALIQPIS, :VRALIQCOFINS,
       :CDCEST, :CDIMPOSTO, :CDFILIAL, :NRORG, :CDPRODUTO, :IDTPIMPOSFIS)
    ";  
    
    const adqGrupoPDV = "
    	SELECT PV.CDGRPRODPDV,
		  FI.CDSEGMER
		FROM FILIAL FI 
		LEFT JOIN PARAVEND PV
		ON (FI.CDFILIAL = PV.CDFILIAL)
		WHERE (FI.CDFILIAL   = :CDFILIAL) AND (FI.NRORG   = :NRORG)
    ";
    
    const adqModProdFili = "
    	SELECT P.CDFILIAL,
		  P.IDUTMODPRODFIL
		FROM PARAMFILIAL P
		WHERE (P.CDFILIAL = :CDFILIAL)
		AND (P.NRORG      = :NRORG)
    ";
    
    const filterModProd = "
    SELECT PS.CDPRODUTO,
       PR.NMPRODUTO,
       PR.CDARVPROD,
       PR.CDBARPRODUTO,
       PR.NRORG,
       A.CDIMPOSTO,
       A.VRPEALIMPFIS,
       A.IDTPIMPOSFIS,
       A.SGIMPOSTO,
       A.NMIMPOSTO,
       A.CDFILIAL,
       A.IDINCIDEPISCOF,
       :CDSEGMER AS CDSEGMER,
       A.VRALIQIBPT,
       A.VRALIQIBPTES,
       A.CDCSTICMS,
       A.CDCSTPISCOF,
       A.CDCFOPPFIS,
       DECODE(A.CDCFOPPFIS, NULL, NULL, A.VRALIQPIS) AS VRALIQPIS,
       DECODE(A.CDCFOPPFIS, NULL, NULL, A.VRALIQCOFINS) AS VRALIQCOFINS,
       A.VRPERCREDUCAO,	
       A.IDMODALBASECALC,
       A.CDCEST
		FROM PRODUTOSEG PG
		JOIN PRODUTO PR ON PR.NRORG = PG.NRORG
		JOIN
		  (SELECT DISTINCT P.CDPRODUTO
		   FROM PRSUBGRPROD P,
		        PARAVEND PE
		   WHERE (PE.CDFILIAL = :CDFILIAL)
		     AND (PE.NRORG = :NRORG)
		     AND (P.CDGRUPPROD = PE.CDGRPRODPDV)
		     AND ((P.CDFILISUBGR = 'P')
		          OR (P.CDFILISUBGR = :CDFILIAL)) ) PS ON (PS.CDPRODUTO = PG.CDPRODUTO)
		AND (PR.CDPRODUTO = PS.CDPRODUTO)
		LEFT JOIN
		  (SELECT COUNT(*) AS NRCOMPPROD,
		          CDPRODUTO
		   FROM ROTFABRICA
		   GROUP BY CDPRODUTO) R ON (R.CDPRODUTO = PR.CDPRODUTO)
		LEFT JOIN
		  (SELECT COUNT(*) AS NRCOMPPRODL,
		          CDPRODUTO
		   FROM ROTFABLOCAL
		   WHERE (CDFILIAL = :CDFILIAL)
		     AND NRORG = :NRORG
		   GROUP BY CDPRODUTO) F ON (F.CDPRODUTO = PR.CDPRODUTO)
		LEFT JOIN
		  (SELECT AL.CDFILIAL,
		          AL.CDPRODUTO,
		          AL.CDIMPOSTO,
		          AL.VRPEALIMPFIS,
		          AL.IDTPIMPOSFIS,
		          IM.SGIMPOSTO,
		          IM.NMIMPOSTO,
		          AL.IDINCIDEPISCOF,
		          AL.VRALIQIBPT,
		          AL.VRALIQIBPTES,
		          AL.CDCSTICMS,
		          AL.CDCSTPISCOF,
		          AL.CDCFOPPFIS,
		          AL.VRALIQPIS,
		          AL.VRALIQCOFINS,
		          AL.VRPERCREDUCAO,
		          AL.IDMODALBASECALC,
		          AL.CDCEST
		   FROM ALIQIMPFIS AL,
		        IMPOSTO IM
		   WHERE AL.CDIMPOSTO = IM.CDIMPOSTO
		     AND AL.CDFILIAL = :CDFILIAL
		     AND AL.NRORG = :NRORG ) A ON (A.CDPRODUTO = PR.CDPRODUTO)
		WHERE (PG.CDSEGMER = :CDSEGMER)
		  AND (PG.NRORG = :NRORG)
		  AND ((PR.CDARVPROD LIKE :CDARVPROD ||'%'))
		  AND (PR.CDNVPRODUTO = :CDNVPRODUTO)
		ORDER BY PR.CDPRODUTO";
		
	const filterImpProdSegFam = "
		SELECT PS.CDPRODUTO,
	       PR.NMPRODUTO,
	       PR.CDARVPROD,
	       PR.CDBARPRODUTO,
	       PR.NRORG,
	       A.CDIMPOSTO,
	       A.VRPEALIMPFIS,
	       A.IDTPIMPOSFIS,
	       A.SGIMPOSTO,
	       A.NMIMPOSTO,
	       A.CDFILIAL,
	       A.IDINCIDEPISCOF,
	       :CDSEGMER AS CDSEGMER,
	       A.VRALIQIBPT,
	       A.VRALIQIBPTES,
	       A.CDCSTICMS,
	       A.CDCSTPISCOF,
	       A.CDCFOPPFIS,
	       DECODE(A.CDCFOPPFIS, NULL, NULL, A.VRALIQPIS) AS VRALIQPIS,
	       DECODE(A.CDCFOPPFIS, NULL, NULL, A.VRALIQCOFINS) AS VRALIQCOFINS,
	       A.VRPERCREDUCAO,
	       A.IDMODALBASECALC,
	       A.CDCEST
	FROM PRODUTOSEG PG JOIN
	     PRODUTO PR ON 
	     PR.NRORG = PG.NRORG
	     JOIN
	  ( SELECT DISTINCT P.CDPRODUTO
	   FROM PRSUBGRPROD P,
	        PARAVEND PE
	   WHERE ( PE.CDFILIAL = :CDFILIAL )
	     AND ( P.NRORG = :NRORG )
	     AND ( P.CDGRUPPROD = PE.CDGRPRODPDV )
	     AND ( ( P.CDFILISUBGR = 'P' )
	          OR ( P.CDFILISUBGR = :CDFILIAL ) ) ) PS ON
	    PS.CDPRODUTO = PR.CDPRODUTO AND
	    PS.CDPRODUTO = PG.CDPRODUTO 
	    
	    LEFT JOIN 
	  ( SELECT COUNT(*) AS NRCOMPPROD,
	           CDPRODUTO
	   FROM ROTFABRICA
	   GROUP BY CDPRODUTO ) R ON
	   ( R.CDPRODUTO = PR.CDPRODUTO )
	  LEFT JOIN
	  ( SELECT COUNT(*) AS NRCOMPPRODL,
	           CDPRODUTO
	   FROM ROTFABLOCAL
	   WHERE ( CDFILIAL = :CDFILIAL )
	   GROUP BY CDPRODUTO ) F ON
	    ( F.CDPRODUTO = PR.CDPRODUTO )
	  LEFT JOIN
	  ( SELECT AL.CDFILIAL,
	           AL.CDPRODUTO,
	           AL.CDIMPOSTO,
	           AL.VRPEALIMPFIS,
	           AL.IDTPIMPOSFIS,
	           IM.SGIMPOSTO,
	           IM.NMIMPOSTO,
	           AL.IDINCIDEPISCOF,
	           AL.VRALIQIBPT,
	           AL.VRALIQIBPTES,
	           AL.CDCSTICMS,
	           AL.CDCSTPISCOF,
	           AL.CDCFOPPFIS,
	           AL.VRALIQPIS,
	           AL.VRALIQCOFINS,
	           AL.VRPERCREDUCAO,
	           AL.IDMODALBASECALC,
	           AL.CDCEST
	   FROM ALIQIMPFIS AL,
	        IMPOSTO IM
	   WHERE AL.CDIMPOSTO = IM.CDIMPOSTO
	     AND AL.CDFILIAL = :CDFILIAL
	     AND AL.NRORG = :NRORG ) A ON
	     ( A.CDPRODUTO = PR.CDPRODUTO )
	WHERE ( PG.CDSEGMER = :CDSEGMER )
	  AND ( PG.NRORG = :NRORG )
	  AND ( PR.CDARVPROD = :CDARVPROD)
	  AND ( PR.CDNVPRODUTO = :CDNVPRODUTO )
	ORDER BY PR.CDPRODUTO";
	
	const filterImpProdFamilia = "
			SELECT PS.CDPRODUTO,
			       PR.CDARVPROD,
			       PR.NMPRODUTO,
			       PR.CDBARPRODUTO,
			       PR.NRORG,
			       A.CDIMPOSTO,
			       A.VRPEALIMPFIS,
			       A.IDTPIMPOSFIS,
			       A.SGIMPOSTO,
			       A.NMIMPOSTO,
			       A.CDFILIAL,
			       A.IDINCIDEPISCOF,
			       :CDSEGMER AS CDSEGMER,
			       A.VRALIQIBPT,
			       A.VRALIQIBPTES,
			       A.CDCSTICMS,
			       A.CDCSTPISCOF,
			       A.CDCFOPPFIS,
			       DECODE(A.CDCFOPPFIS, NULL, NULL, A.VRALIQPIS) AS VRALIQPIS,
			       DECODE(A.CDCFOPPFIS, NULL, NULL, A.VRALIQCOFINS) AS VRALIQCOFINS,
			       A.VRPERCREDUCAO,
			       A.IDMODALBASECALC,
		    	   A.CDCEST
		FROM PRODUTO PR JOIN
		     PARAVEND PG ON
		     PR.NRORG = PG.NRORG
		     JOIN 
		  (SELECT DISTINCT CDPRODUTO,
		                   CDGRUPPROD
		   FROM PRSUBGRPROD
		   WHERE ((CDFILISUBGR = 'P')
		          OR (CDFILISUBGR = :CDFILIAL)) ) PS ON
		     (PR.CDPRODUTO = PS.CDPRODUTO)
		     AND (PG.CDGRPRODPDV = PS.CDGRUPPROD)
		     LEFT JOIN
		  (SELECT COUNT(*) AS NRCOMPPROD,
		          CDPRODUTO
		   FROM ROTFABRICA
		   GROUP BY CDPRODUTO) R ON
		   (PR.CDPRODUTO = R.CDPRODUTO)
		   LEFT JOIN
		  (SELECT COUNT(*) AS NRCOMPPRODL,
		          CDPRODUTO
		   FROM ROTFABLOCAL
		   WHERE (CDFILIAL = :CDFILIAL)
		     AND (NRORG = :NRORG)
		   GROUP BY CDPRODUTO) F ON
		   (PR.CDPRODUTO = F.CDPRODUTO)
		   LEFT JOIN
		  (SELECT AL.CDFILIAL,
		          AL.CDPRODUTO,
		          AL.CDIMPOSTO,
		          AL.VRPEALIMPFIS,
		          AL.IDTPIMPOSFIS,
		          IM.SGIMPOSTO,
		          IM.NMIMPOSTO,
		          AL.IDINCIDEPISCOF,
		          AL.VRALIQIBPT,
		          AL.VRALIQIBPTES,
		          AL.CDCSTICMS,
		          AL.CDCSTPISCOF,
		          AL.CDCFOPPFIS,
		          AL.VRALIQPIS,
		          AL.VRALIQCOFINS,
		          AL.VRPERCREDUCAO,
		          AL.IDMODALBASECALC,
		          AL.CDCEST
		   FROM ALIQIMPFIS AL,
		        IMPOSTO IM
		   WHERE AL.CDIMPOSTO = IM.CDIMPOSTO
		     AND AL.CDFILIAL = :CDFILIAL
		     AND AL.NRORG = :NRORG ) A ON 
		     (PR.CDPRODUTO = A.CDPRODUTO)     
		WHERE (NVL(PR.IDPRODATIVPR, 'S') = 'S')
		  AND (PG.NRORG = :NRORG)
		  AND ((PR.CDARVPROD = :CDARVPROD))
		  AND (PR.CDNVPRODUTO = :CDNVPRODUTO)
		  AND (PG.CDFILIAL = :CDFILIAL)
		ORDER BY PR.CDPRODUTO";
	
	const filterImpProdSegmento = "
		SELECT PR.CDPRODUTO,
	       PR.CDARVPROD,
	       PR.NMPRODUTO,
	       PR.CDBARPRODUTO,
	       PR.NRORG,
	       A.CDIMPOSTO,
	       A.VRPEALIMPFIS,
	       A.IDTPIMPOSFIS,
	       A.SGIMPOSTO,
	       A.NMIMPOSTO,
	       A.CDFILIAL,
	       A.IDINCIDEPISCOF,
	       :CDSEGMER AS CDSEGMER,
	       A.VRALIQIBPT,
	       A.VRALIQIBPTES,
	       A.CDCSTICMS,
	       A.CDCSTPISCOF,
	       A.CDCFOPPFIS,
	       DECODE(A.CDCFOPPFIS, NULL, NULL, A.VRALIQPIS) AS VRALIQPIS,
	       DECODE(A.CDCFOPPFIS, NULL, NULL, A.VRALIQCOFINS) AS VRALIQCOFINS,
	       A.VRPERCREDUCAO,
	       A.IDMODALBASECALC,
	       A.CDCEST
	FROM PRODUTOSEG S JOIN
	     PRODUTO PR ON
	     (PR.CDPRODUTO = S.CDPRODUTO) AND
	     (PR.NRORG     = S.NRORG)
	     LEFT JOIN
	  (SELECT COUNT(*) AS NRCOMPPROD,
	          CDPRODUTO
	   FROM ROTFABRICA
	   GROUP BY CDPRODUTO) R ON
	     (PR.CDPRODUTO = R.CDPRODUTO)
	    LEFT JOIN 
	  (SELECT COUNT(*) AS NRCOMPPRODL,
	          CDPRODUTO
	   FROM ROTFABLOCAL
	   WHERE (CDFILIAL = :CDFILIAL)
	     AND (NRORG = :NRORG)
	   GROUP BY CDPRODUTO) F ON
	     (PR.CDPRODUTO = F.CDPRODUTO)
	    LEFT JOIN
	    (SELECT AL.CDFILIAL,
	          AL.CDPRODUTO,
	          AL.CDIMPOSTO,
	          AL.VRPEALIMPFIS,
	          AL.IDTPIMPOSFIS,
	          IM.SGIMPOSTO,
	          IM.NMIMPOSTO,
	          AL.IDINCIDEPISCOF,
	          AL.VRALIQIBPT,
	          AL.VRALIQIBPTES,
	          AL.CDCSTICMS,
	          AL.CDCSTPISCOF,
	          AL.CDCFOPPFIS,
	          AL.VRALIQPIS,
	          AL.VRALIQCOFINS,
	          AL.VRPERCREDUCAO,
	          AL.IDMODALBASECALC,
	          AL.CDCEST
	   FROM ALIQIMPFIS AL,
	        IMPOSTO IM
	   WHERE AL.CDIMPOSTO = IM.CDIMPOSTO
	     AND AL.CDFILIAL = :CDFILIAL
	     AND AL.NRORG = :NRORG ) A ON
	     (PR.CDPRODUTO = A.CDPRODUTO)     
	WHERE (S.CDSEGMER = :CDSEGMER)
	  AND (S.NRORG = :NRORG)
	  AND (NVL(PR.IDPRODATIVPR, 'S') = 'S')
	  AND (PR.CDARVPROD = :CDARVPROD)
	  AND (PR.CDNVPRODUTO = :CDNVPRODUTO)
	ORDER BY PR.CDPRODUTO
	";
}